@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONCOPYTEST_H
-#define FILTERACTIONCOPYTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,11 +13,10 @@ class FilterActionCopyTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionCopyTest(QObject *parent = nullptr);
-    ~FilterActionCopyTest();
+    ~FilterActionCopyTest() override;
 private Q_SLOTS:
     void shouldBeEmpty();
     void shouldHaveSieveRequires();
     void shouldHaveRequiresPart();
 };
 
-#endif // FILTERACTIONCOPYTEST_H
