@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONMISSINGTEMPLATEDIALOGTEST_H
-#define FILTERACTIONMISSINGTEMPLATEDIALOGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class FilterActionMissingTemplateDialogTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionMissingTemplateDialogTest(QObject *parent = nullptr);
-    ~FilterActionMissingTemplateDialogTest();
+    ~FilterActionMissingTemplateDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // FILTERACTIONMISSINGTEMPLATEDIALOGTEST_H
