@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONMISSINGSOUNDURLDIALOG_H
-#define FILTERACTIONMISSINGSOUNDURLDIALOG_H
+#pragma once
 
 #include <QDialog>
 class KUrlRequester;
@@ -16,7 +15,7 @@ class FilterActionMissingSoundUrlDialog : public QDialog
     Q_OBJECT
 public:
     explicit FilterActionMissingSoundUrlDialog(const QString &filtername, const QString &argStr, QWidget *parent = nullptr);
-    ~FilterActionMissingSoundUrlDialog();
+    ~FilterActionMissingSoundUrlDialog() override;
     Q_REQUIRED_RESULT QString soundUrl() const;
 
 private:
@@ -26,4 +25,3 @@ private:
 };
 }
 
-#endif // FILTERACTIONMISSINGSOUNDURLDIALOG_H
