@@ -5,18 +5,17 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
-#ifndef MAILCOMMON_MAILFILTER_H
-#define MAILCOMMON_MAILFILTER_H
+#pragma once
 
 #include "mailcommon_export.h"
 
 #include "mailcommon/filteraction.h"
 #include "mailcommon/searchpattern.h"
 
-#include <AkonadiCore/collection.h>
+#include <Akonadi/Collection>
 #include <QKeySequence>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #include <QDataStream>
 #include <QVector>
@@ -340,4 +339,3 @@ MAILCOMMON_EXPORT QDataStream &operator<<(QDataStream &stream, const MailFilter
 MAILCOMMON_EXPORT QDataStream &operator>>(QDataStream &stream, MailFilter &filter);
 }
 
-#endif /*MAILCOMMON_MAILFILTER_H*/
