@@ -8,11 +8,11 @@
 #include "backupjob.h"
 
 #include "mailcommon_debug.h"
-#include <CollectionDeleteJob>
-#include <CollectionFetchJob>
-#include <CollectionFetchScope>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
+#include <Akonadi/CollectionDeleteJob>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 #include <PimCommon/BroadcastStatus>
 
 #include <KMime/Message>
